@@ -24,15 +24,15 @@
 #include <cuda/std/__concepts/same_as.h>
 #include <cuda/std/__type_traits/remove_cvref.h>
 
-#include <cuda/std/__cccl/prologue.h>
-
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
+#if !defined(_CCCL_NO_VARIABLE_TEMPLATES)
+
 template <class _Tp, class _Up>
 _CCCL_CONCEPT __different_from = !same_as<remove_cvref_t<_Tp>, remove_cvref_t<_Up>>;
 
+#endif // ^^^ !_CCCL_NO_VARIABLE_TEMPLATES
+
 _LIBCUDACXX_END_NAMESPACE_STD
 
-#include <cuda/std/__cccl/epilogue.h>
-
 #endif // _LIBCUDACXX___CONCEPTS_DIFFERENT_FROM_H
