@@ -23,8 +23,6 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
-from __future__ import annotations
-
 
 import warnings
 
@@ -771,7 +769,7 @@ def stft(
     .. math:: x[n]=\frac{\sum_{t}x_{t}[n]w[n-tH]}{\sum_{t}w^{2}[n-tH]}
 
     The NOLA constraint ensures that every normalization term that appears
-    in the denominator of the OLA reconstruction equation is nonzero. Whether a
+    in the denomimator of the OLA reconstruction equation is nonzero. Whether a
     choice of `window`, `nperseg`, and `noverlap` satisfy this constraint can
     be tested with `check_NOLA`.
 
@@ -1097,7 +1095,7 @@ def istft(
         if len(win.shape) != 1:
             raise ValueError("window must be 1-D")
         if win.shape[0] != nperseg:
-            raise ValueError("window must have length of {}".format(nperseg))
+            raise ValueError("window must have length of {0}".format(nperseg))
 
     ifunc = cupy.fft.irfft if input_onesided else cupy.fft.ifft
     xsubs = ifunc(Zxx, axis=-2, n=nfft)[..., :nperseg, :]
@@ -1298,7 +1296,7 @@ def spectrogram(
     window, nperseg = _triage_segments(
         window, nperseg, input_length=x.shape[axis])
 
-    # Less overlap than welch, so samples are more statistically independent
+    # Less overlap than welch, so samples are more statisically independent
     if noverlap is None:
         noverlap = nperseg // 8
 
